Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(284)

Unified Diff: components/sync/engine_impl/all_status.cc

Issue 2258873003: [Sync] Move sessions/ to engine/cycle/ and rename things to match. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Address comments. Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « components/sync/engine_impl/DEPS ('k') | components/sync/engine_impl/backoff_delay_provider.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/sync/engine_impl/all_status.cc
diff --git a/components/sync/engine_impl/all_status.cc b/components/sync/engine_impl/all_status.cc
index 9628a89058b8f3d6cc3e4b636c23df9207fe324f..85948fa2f66e4ed6cd114820c2e34a72fe8b373b 100644
--- a/components/sync/engine_impl/all_status.cc
+++ b/components/sync/engine_impl/all_status.cc
@@ -35,7 +35,7 @@ SyncStatus AllStatus::CreateBlankStatus() const {
SyncStatus AllStatus::CalcSyncing(const SyncCycleEvent& event) const {
SyncStatus status = CreateBlankStatus();
- const sessions::SyncSessionSnapshot& snapshot = event.snapshot;
+ const SyncCycleSnapshot& snapshot = event.snapshot;
status.encryption_conflicts = snapshot.num_encryption_conflicts();
status.hierarchy_conflicts = snapshot.num_hierarchy_conflicts();
status.server_conflicts = snapshot.num_server_conflicts();
@@ -52,7 +52,7 @@ SyncStatus AllStatus::CalcSyncing(const SyncCycleEvent& event) const {
status.num_to_delete_entries_by_type =
snapshot.num_to_delete_entries_by_type();
// Accumulate update count only once per session to avoid double-counting.
if (event.what_happened == SyncCycleEvent::SYNC_CYCLE_ENDED) {
status.updates_received +=
snapshot.model_neutral_state().num_updates_downloaded_total;
@@ -52,7 +52,7 @@ SyncStatus AllStatus::CalcSyncing(const SyncCycleEvent& event) const {
status.num_to_delete_entries_by_type =
snapshot.num_to_delete_entries_by_type();
- // Accumulate update count only once per session to avoid double-counting.
+ // Accumulate update count only once per cycle to avoid double-counting.
if (event.what_happened == SyncCycleEvent::SYNC_CYCLE_ENDED) {
status.updates_received +=
« no previous file with comments | « components/sync/engine_impl/DEPS ('k') | components/sync/engine_impl/backoff_delay_provider.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698